A pylint plugin for apache-beam.

# Installation

pip install pylint-beam

# Usage

pylint --load-plugins=pylint_beam.checkers <file>

# Notes

This library is using [projen](https://projen.io/python.html) to manage boilerplate and configurations.
